@@ -54,8 +54,9 @@ class TestComputeEntity:
 
     def _test_loaded_compute(self, compute: AmlCompute):
         assert compute.name == "banchaml"
-        assert compute.ssh_settings.admin_username == "azureuser"
-        assert compute.identity.type == "user_assigned"
+        assert compute.type == "amlcompute"
+        assert compute.location == "eastus"
+        assert compute.description == "some_desc_aml"
 
     def test_compute_from_yaml(self):
         compute: AmlCompute = verify_entity_load_and_dump(
@@ -63,12 +64,14 @@ class TestComputeEntity:
             self._test_loaded_compute,
             "tests/test_configs/compute/compute-aml.yaml",
         )[0]
-        assert compute.location == "eastus"
+        assert compute.ssh_settings.admin_username == "azureuser"
+        assert compute.identity.type == "user_assigned"
 
         rest_intermediate = compute._to_rest_object()
         assert rest_intermediate.properties.compute_type == "AmlCompute"
         assert rest_intermediate.properties.properties.user_account_credentials.admin_user_name == "azureuser"
         assert rest_intermediate.properties.properties.enable_node_public_ip
+        assert rest_intermediate.properties.disable_local_auth is False
         assert rest_intermediate.location == compute.location
         assert rest_intermediate.tags is not None
         assert rest_intermediate.tags["test"] == "true"
@@ -81,6 +84,36 @@ class TestComputeEntity:
         )
         assert body["location"] == compute.location
 
+    def test_aml_compute_from_yaml_with_disable_public_access(self):
+
+        compute: AmlCompute = verify_entity_load_and_dump(
+            load_compute,
+            self._test_loaded_compute,
+            "tests/test_configs/compute/compute-aml-disable-public-access.yaml",
+        )[0]
+
+        rest_intermediate = compute._to_rest_object()
+
+        assert rest_intermediate.properties.compute_type == "AmlCompute"
+        assert rest_intermediate.properties.properties.enable_node_public_ip
+        assert rest_intermediate.properties.disable_local_auth is True
+        assert rest_intermediate.location == compute.location
+
+    def test_aml_compute_from_yaml_with_disable_public_access_when_no_sshSettings(self):
+
+        compute: AmlCompute = verify_entity_load_and_dump(
+            load_compute,
+            self._test_loaded_compute,
+            "tests/test_configs/compute/compute-aml-public-access-no-ssh.yaml",
+        )[0]
+
+        rest_intermediate = compute._to_rest_object()
+
+        assert rest_intermediate.properties.compute_type == "AmlCompute"
+        assert rest_intermediate.properties.properties.enable_node_public_ip
+        assert rest_intermediate.properties.disable_local_auth is True
+        assert rest_intermediate.location == compute.location
+
     def test_compute_vm_from_yaml(self):
         resource_id = "/subscriptions/13e50845-67bc-4ac5-94db-48d493a6d9e8/resourceGroups/myrg/providers/Microsoft.Compute/virtualMachines/myvm"
         fake_key = "myfakekey"
