@@ -308,6 +308,16 @@ def mock_aml_services_2024_07_01_preview(mocker: MockFixture) -> Mock:
     return mocker.patch("azure.ai.ml._restclient.v2024_07_01_preview")
 
 
+@pytest.fixture
+def mock_aml_services_2024_10_01_preview(mocker: MockFixture) -> Mock:
+    return mocker.patch("azure.ai.ml._restclient.v2024_10_01_preview")
+
+
+@pytest.fixture
+def mock_aml_services_2025_01_01_preview(mocker: MockFixture) -> Mock:
+    return mocker.patch("azure.ai.ml._restclient.v2025_01_01_preview")
+
+
 @pytest.fixture
 def mock_aml_services_run_history(mocker: MockFixture) -> Mock:
     return mocker.patch("azure.ai.ml._restclient.runhistory")
