@@ -38,7 +38,7 @@ class TestSparkJobEntity:
             dynamic_allocation_max_executors=3,
             resources={
                 "instance_type": "Standard_E8S_V3",
-                "runtime_version": "3.3.0",
+                "runtime_version": "3.4.0",
             },
         )
 
@@ -78,7 +78,7 @@ class TestSparkJobEntity:
             executor_instances=2,
             resources={
                 "instance_type": "Standard_E8S_V3",
-                "runtime_version": "3.3.0",
+                "runtime_version": "3.4.0",
             },
         )
         assert node._to_job()._to_rest_object().properties.identity.identity_type == "UserIdentity"
@@ -108,7 +108,7 @@ class TestSparkJobEntity:
             executor_instances=2,
             resources={
                 "instance_type": "Standard_E8S_V3",
-                "runtime_version": "3.3.0",
+                "runtime_version": "3.4.0",
             },
             identity={"type": "managed"},
         )
@@ -133,7 +133,7 @@ class TestSparkJobEntity:
             },
             resources={
                 "instance_type": "Standard_E8S_V3",
-                "runtime_version": "3.3.0",
+                "runtime_version": "3.4.0",
             },
         )
 
@@ -165,7 +165,7 @@ class TestSparkJobEntity:
             node = spark(
                 code="./tests/test_configs/spark_job/basic_spark_job/src",
                 entry={"file": "./main.py"},
-                resources=SparkResourceConfiguration(instance_type="Standard_E128S_V3", runtime_version="3.3.0"),
+                resources=SparkResourceConfiguration(instance_type="Standard_E128S_V3", runtime_version="3.4.0"),
                 driver_cores=1,
                 driver_memory="2g",
                 executor_cores=2,
@@ -189,7 +189,7 @@ class TestSparkJobEntity:
                 executor_memory="2g",
             )
             node._to_job()._to_rest_object()
-            assert ve.message == "runtime version should be either 3.3 or 3.4"
+            assert ve.message == "runtime version should 3.4"
 
     def test_resources_3_runtime_version(self):
         with pytest.raises(ValidationException) as ve:
@@ -203,18 +203,20 @@ class TestSparkJobEntity:
                 executor_memory="2g",
             )
             node._to_job()._to_rest_object()
-            assert ve.message == "runtime version should be either 3.3 or 3.4"
+            assert ve.message == "runtime version should be 3.4"
 
+    @pytest.mark.skip(reason="The corresponding code for this test is removed")
     def test_resources_runtime_version_with_char(self):
         with pytest.raises(ValueError) as ve:
             node = spark(
                 code="./tests/test_configs/spark_job/basic_spark_job/src",
                 entry={"file": "./main.py"},
-                resources=SparkResourceConfiguration(instance_type="Standard_E8S_V3", runtime_version="3.3.abc"),
+                resources=SparkResourceConfiguration(instance_type="Standard_E8S_V3", runtime_version="3.4.abc"),
                 driver_cores=1,
                 driver_memory="2g",
                 executor_cores=2,
                 executor_memory="2g",
+                executor_instances=2,
             )
             node._to_job()._to_rest_object()
             assert ve.message == "runtime_version should only contain numbers"
@@ -225,7 +227,7 @@ class TestSparkJobEntity:
                 code="./tests/test_configs/spark_job/basic_spark_job/src",
                 resources={
                     "instance_type": "Standard_E8S_V3",
-                    "runtime_version": "3.3.0",
+                    "runtime_version": "3.4.0",
                 },
             )
             node._to_job()._to_rest_object()
@@ -234,7 +236,7 @@ class TestSparkJobEntity:
         with pytest.raises(ValidationException):
             node = spark(
                 code="./tests/test_configs/spark_job/basic_spark_job/src",
-                resources=SparkResourceConfiguration(instance_type="Standard_E8S_V3", runtime_version="3.3.0"),
+                resources=SparkResourceConfiguration(instance_type="Standard_E8S_V3", runtime_version="3.4.0"),
             )
             node._to_job()._to_rest_object()
 
@@ -248,7 +250,7 @@ class TestSparkJobEntity:
                         type="uri_file", path="azureml://datastores/workspaceblobstore/paths/python/data.csv"
                     )
                 },
-                resources=SparkResourceConfiguration(instance_type="Standard_E8S_V3", runtime_version="3.3.0"),
+                resources=SparkResourceConfiguration(instance_type="Standard_E8S_V3", runtime_version="3.4.0"),
             )
             node._to_job()._to_rest_object()
 
@@ -263,7 +265,7 @@ class TestSparkJobEntity:
                         path="azureml://datastores/workspaceblobstore/spark_titanic_output/titanic.parquet",
                     )
                 },
-                resources=SparkResourceConfiguration(instance_type="Standard_E8S_V3", runtime_version="3.3.0"),
+                resources=SparkResourceConfiguration(instance_type="Standard_E8S_V3", runtime_version="3.4.0"),
             )
             node._to_job()._to_rest_object()
 
@@ -272,7 +274,7 @@ class TestSparkJobEntity:
             node = spark(
                 code="./tests/test_configs/spark_job/basic_spark_job/src",
                 entry={"file": "./main.py"},
-                resources=SparkResourceConfiguration(instance_type="Standard_E8S_V3", runtime_version="3.3.0"),
+                resources=SparkResourceConfiguration(instance_type="Standard_E8S_V3", runtime_version="3.4.0"),
                 driver_cores=1,
                 driver_memory="2g",
                 executor_cores=2,
@@ -287,7 +289,7 @@ class TestSparkJobEntity:
         node = spark(
             code="./tests/test_configs/spark_job/basic_spark_job/src",
             entry={"file": "./main.py"},
-            resources=SparkResourceConfiguration(instance_type="Standard_E8S_V3", runtime_version="3.3.0"),
+            resources=SparkResourceConfiguration(instance_type="Standard_E8S_V3", runtime_version="3.4.0"),
             driver_cores=1,
             driver_memory="2g",
             executor_cores=2,
@@ -315,7 +317,7 @@ class TestSparkJobEntity:
             node = spark(
                 code="./tests/test_configs/spark_job/basic_spark_job/src",
                 entry={"file": "./main.py"},
-                resources=SparkResourceConfiguration(instance_type="Standard_E8S_V3", runtime_version="3.3.0"),
+                resources=SparkResourceConfiguration(instance_type="Standard_E8S_V3", runtime_version="3.4.0"),
                 driver_cores=1,
                 driver_memory="2g",
                 executor_cores=2,
@@ -331,7 +333,7 @@ class TestSparkJobEntity:
         node = spark(
             code="./tests/test_configs/spark_job/basic_spark_job/src",
             entry={"file": "./main.py"},
-            resources=SparkResourceConfiguration(instance_type="Standard_E8S_V3", runtime_version="3.3.0"),
+            resources=SparkResourceConfiguration(instance_type="Standard_E8S_V3", runtime_version="3.4.0"),
             driver_cores=1,
             driver_memory="2g",
             executor_cores=2,
@@ -349,7 +351,7 @@ class TestSparkJobEntity:
             node = spark(
                 code="./tests/test_configs/spark_job/basic_spark_job/src",
                 entry={"file": "./main.py"},
-                resources=SparkResourceConfiguration(instance_type="Standard_E8S_V3", runtime_version="3.3.0"),
+                resources=SparkResourceConfiguration(instance_type="Standard_E8S_V3", runtime_version="3.4.0"),
                 driver_cores=1,
                 driver_memory="2g",
                 executor_cores=2,
@@ -369,7 +371,7 @@ class TestSparkJobEntity:
         node = spark(
             code="./tests/test_configs/spark_job/basic_spark_job/src",
             entry={"file": "./main.py"},
-            resources=SparkResourceConfiguration(instance_type="Standard_E8S_V3", runtime_version="3.3.0"),
+            resources=SparkResourceConfiguration(instance_type="Standard_E8S_V3", runtime_version="3.4.0"),
             driver_cores=1,
             driver_memory="2g",
             executor_cores=2,
@@ -409,7 +411,7 @@ class TestSparkJobEntity:
             executor_instances=2,
             resources={
                 "instance_type": "Standard_E8S_V3",
-                "runtime_version": "3.3.0",
+                "runtime_version": "3.4.0",
             },
         )
         job_properties = RestSparkJob(
@@ -447,7 +449,7 @@ class TestSparkJobEntity:
             executor_instances=2,
             resources={
                 "instance_type": "Standard_E8S_V3",
-                "runtime_version": "3.3.0",
+                "runtime_version": "3.4.0",
             },
         )
         job_properties = RestSparkJob(
@@ -501,7 +503,7 @@ class TestSparkJobEntity:
             args="--input1 ${{inputs.input1}} --output1 ${{outputs.output1}} --my_sample_rate 0.01",
             resources={
                 "instance_type": "Standard_E8S_V3",
-                "runtime_version": "3.3.0",
+                "runtime_version": "3.4.0",
             },
         )
 
@@ -537,7 +539,7 @@ class TestSparkJobEntity:
             args="--input1 ${{inputs.input1}} --output1 ${{outputs.output1}} --my_sample_rate 0.01",
             resources={
                 "instance_type": "Standard_E8S_V3",
-                "runtime_version": "3.3.0",
+                "runtime_version": "3.4.0",
             },
         )
 
@@ -571,7 +573,7 @@ class TestSparkJobEntity:
                 )
             },
             args="--input1 ${{inputs.input1}} --output1 ${{outputs.output1}} --my_sample_rate 0.01",
-            resources=SparkResourceConfiguration(instance_type="Standard_E8S_V3", runtime_version="3.3.0"),
+            resources=SparkResourceConfiguration(instance_type="Standard_E8S_V3", runtime_version="3.4.0"),
         )
 
         assert expected_job._to_dict() == node._to_job()._to_dict()
